Documentation
¶
Index ¶
- Constants
- Variables
- func Resource(resource string) schema.GroupResource
- type BasicSchedulingPolicy
- func (in *BasicSchedulingPolicy) DeepCopy() *BasicSchedulingPolicy
- func (in *BasicSchedulingPolicy) DeepCopyInto(out *BasicSchedulingPolicy)
- func (m *BasicSchedulingPolicy) Marshal() (dAtA []byte, err error)
- func (m *BasicSchedulingPolicy) MarshalTo(dAtA []byte) (int, error)
- func (m *BasicSchedulingPolicy) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in BasicSchedulingPolicy) OpenAPIModelName() string
- func (m *BasicSchedulingPolicy) Reset()
- func (m *BasicSchedulingPolicy) Size() (n int)
- func (this *BasicSchedulingPolicy) String() string
- func (BasicSchedulingPolicy) SwaggerDoc() map[string]string
- func (m *BasicSchedulingPolicy) Unmarshal(dAtA []byte) error
- type GangSchedulingPolicy
- func (in *GangSchedulingPolicy) DeepCopy() *GangSchedulingPolicy
- func (in *GangSchedulingPolicy) DeepCopyInto(out *GangSchedulingPolicy)
- func (m *GangSchedulingPolicy) Marshal() (dAtA []byte, err error)
- func (m *GangSchedulingPolicy) MarshalTo(dAtA []byte) (int, error)
- func (m *GangSchedulingPolicy) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in GangSchedulingPolicy) OpenAPIModelName() string
- func (m *GangSchedulingPolicy) Reset()
- func (m *GangSchedulingPolicy) Size() (n int)
- func (this *GangSchedulingPolicy) String() string
- func (GangSchedulingPolicy) SwaggerDoc() map[string]string
- func (m *GangSchedulingPolicy) Unmarshal(dAtA []byte) error
- type PodGroup
- func (in *PodGroup) DeepCopy() *PodGroup
- func (in *PodGroup) DeepCopyInto(out *PodGroup)
- func (m *PodGroup) Marshal() (dAtA []byte, err error)
- func (m *PodGroup) MarshalTo(dAtA []byte) (int, error)
- func (m *PodGroup) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in PodGroup) OpenAPIModelName() string
- func (m *PodGroup) Reset()
- func (m *PodGroup) Size() (n int)
- func (this *PodGroup) String() string
- func (PodGroup) SwaggerDoc() map[string]string
- func (m *PodGroup) Unmarshal(dAtA []byte) error
- type PodGroupPolicy
- func (in *PodGroupPolicy) DeepCopy() *PodGroupPolicy
- func (in *PodGroupPolicy) DeepCopyInto(out *PodGroupPolicy)
- func (m *PodGroupPolicy) Marshal() (dAtA []byte, err error)
- func (m *PodGroupPolicy) MarshalTo(dAtA []byte) (int, error)
- func (m *PodGroupPolicy) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in PodGroupPolicy) OpenAPIModelName() string
- func (m *PodGroupPolicy) Reset()
- func (m *PodGroupPolicy) Size() (n int)
- func (this *PodGroupPolicy) String() string
- func (PodGroupPolicy) SwaggerDoc() map[string]string
- func (m *PodGroupPolicy) Unmarshal(dAtA []byte) error
- type PriorityClass
- func (in *PriorityClass) DeepCopy() *PriorityClass
- func (in *PriorityClass) DeepCopyInto(out *PriorityClass)
- func (in *PriorityClass) DeepCopyObject() runtime.Object
- func (m *PriorityClass) Marshal() (dAtA []byte, err error)
- func (m *PriorityClass) MarshalTo(dAtA []byte) (int, error)
- func (m *PriorityClass) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in PriorityClass) OpenAPIModelName() string
- func (m *PriorityClass) Reset()
- func (m *PriorityClass) Size() (n int)
- func (this *PriorityClass) String() string
- func (PriorityClass) SwaggerDoc() map[string]string
- func (m *PriorityClass) Unmarshal(dAtA []byte) error
- type PriorityClassList
- func (in *PriorityClassList) DeepCopy() *PriorityClassList
- func (in *PriorityClassList) DeepCopyInto(out *PriorityClassList)
- func (in *PriorityClassList) DeepCopyObject() runtime.Object
- func (m *PriorityClassList) Marshal() (dAtA []byte, err error)
- func (m *PriorityClassList) MarshalTo(dAtA []byte) (int, error)
- func (m *PriorityClassList) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in PriorityClassList) OpenAPIModelName() string
- func (m *PriorityClassList) Reset()
- func (m *PriorityClassList) Size() (n int)
- func (this *PriorityClassList) String() string
- func (PriorityClassList) SwaggerDoc() map[string]string
- func (m *PriorityClassList) Unmarshal(dAtA []byte) error
- type TypedLocalObjectReference
- func (in *TypedLocalObjectReference) DeepCopy() *TypedLocalObjectReference
- func (in *TypedLocalObjectReference) DeepCopyInto(out *TypedLocalObjectReference)
- func (m *TypedLocalObjectReference) Marshal() (dAtA []byte, err error)
- func (m *TypedLocalObjectReference) MarshalTo(dAtA []byte) (int, error)
- func (m *TypedLocalObjectReference) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in TypedLocalObjectReference) OpenAPIModelName() string
- func (m *TypedLocalObjectReference) Reset()
- func (m *TypedLocalObjectReference) Size() (n int)
- func (this *TypedLocalObjectReference) String() string
- func (TypedLocalObjectReference) SwaggerDoc() map[string]string
- func (m *TypedLocalObjectReference) Unmarshal(dAtA []byte) error
- type Workload
- func (in *Workload) DeepCopy() *Workload
- func (in *Workload) DeepCopyInto(out *Workload)
- func (in *Workload) DeepCopyObject() runtime.Object
- func (m *Workload) Marshal() (dAtA []byte, err error)
- func (m *Workload) MarshalTo(dAtA []byte) (int, error)
- func (m *Workload) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in Workload) OpenAPIModelName() string
- func (m *Workload) Reset()
- func (m *Workload) Size() (n int)
- func (this *Workload) String() string
- func (Workload) SwaggerDoc() map[string]string
- func (m *Workload) Unmarshal(dAtA []byte) error
- type WorkloadList
- func (in *WorkloadList) DeepCopy() *WorkloadList
- func (in *WorkloadList) DeepCopyInto(out *WorkloadList)
- func (in *WorkloadList) DeepCopyObject() runtime.Object
- func (m *WorkloadList) Marshal() (dAtA []byte, err error)
- func (m *WorkloadList) MarshalTo(dAtA []byte) (int, error)
- func (m *WorkloadList) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in WorkloadList) OpenAPIModelName() string
- func (m *WorkloadList) Reset()
- func (m *WorkloadList) Size() (n int)
- func (this *WorkloadList) String() string
- func (WorkloadList) SwaggerDoc() map[string]string
- func (m *WorkloadList) Unmarshal(dAtA []byte) error
- type WorkloadSpec
- func (in *WorkloadSpec) DeepCopy() *WorkloadSpec
- func (in *WorkloadSpec) DeepCopyInto(out *WorkloadSpec)
- func (m *WorkloadSpec) Marshal() (dAtA []byte, err error)
- func (m *WorkloadSpec) MarshalTo(dAtA []byte) (int, error)
- func (m *WorkloadSpec) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (in WorkloadSpec) OpenAPIModelName() string
- func (m *WorkloadSpec) Reset()
- func (m *WorkloadSpec) Size() (n int)
- func (this *WorkloadSpec) String() string
- func (WorkloadSpec) SwaggerDoc() map[string]string
- func (m *WorkloadSpec) Unmarshal(dAtA []byte) error
Constants ¶
const GroupName = "scheduling.k8s.io"
GroupName is the group name use in this package
const WorkloadMaxPodGroups = 8
WorkloadMaxPodGroups is the maximum number of pod groups per Workload.
Variables ¶
var ( ErrInvalidLengthGenerated = fmt.Errorf("proto: negative length found during unmarshaling") ErrIntOverflowGenerated = fmt.Errorf("proto: integer overflow") ErrUnexpectedEndOfGroupGenerated = fmt.Errorf("proto: unexpected end of group") )
var ( // TODO: move SchemeBuilder with zz_generated.deepcopy.go to k8s.io/api. // localSchemeBuilder and AddToScheme will stay in k8s.io/kubernetes. SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) AddToScheme = localSchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: "v1alpha1"}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type BasicSchedulingPolicy ¶ added in v0.35.0
type BasicSchedulingPolicy struct {
}
BasicSchedulingPolicy indicates that standard Kubernetes scheduling behavior should be used.
func (*BasicSchedulingPolicy) DeepCopy ¶ added in v0.35.0
func (in *BasicSchedulingPolicy) DeepCopy() *BasicSchedulingPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new BasicSchedulingPolicy.
func (*BasicSchedulingPolicy) DeepCopyInto ¶ added in v0.35.0
func (in *BasicSchedulingPolicy) DeepCopyInto(out *BasicSchedulingPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*BasicSchedulingPolicy) Marshal ¶ added in v0.35.0
func (m *BasicSchedulingPolicy) Marshal() (dAtA []byte, err error)
func (*BasicSchedulingPolicy) MarshalTo ¶ added in v0.35.0
func (m *BasicSchedulingPolicy) MarshalTo(dAtA []byte) (int, error)
func (*BasicSchedulingPolicy) MarshalToSizedBuffer ¶ added in v0.35.0
func (m *BasicSchedulingPolicy) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (BasicSchedulingPolicy) OpenAPIModelName ¶ added in v0.35.0
func (in BasicSchedulingPolicy) OpenAPIModelName() string
OpenAPIModelName returns the OpenAPI model name for this type.
func (*BasicSchedulingPolicy) Reset ¶ added in v0.35.0
func (m *BasicSchedulingPolicy) Reset()
func (*BasicSchedulingPolicy) Size ¶ added in v0.35.0
func (m *BasicSchedulingPolicy) Size() (n int)
func (*BasicSchedulingPolicy) String ¶ added in v0.35.0
func (this *BasicSchedulingPolicy) String() string
func (BasicSchedulingPolicy) SwaggerDoc ¶ added in v0.35.0
func (BasicSchedulingPolicy) SwaggerDoc() map[string]string
func (*BasicSchedulingPolicy) Unmarshal ¶ added in v0.35.0
func (m *BasicSchedulingPolicy) Unmarshal(dAtA []byte) error
type GangSchedulingPolicy ¶ added in v0.35.0
type GangSchedulingPolicy struct {
// MinCount is the minimum number of pods that must be schedulable or scheduled
// at the same time for the scheduler to admit the entire group.
// It must be a positive integer.
//
// +required
MinCount int32 `json:"minCount" protobuf:"varint,1,opt,name=minCount"`
}
GangSchedulingPolicy defines the parameters for gang scheduling.
func (*GangSchedulingPolicy) DeepCopy ¶ added in v0.35.0
func (in *GangSchedulingPolicy) DeepCopy() *GangSchedulingPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GangSchedulingPolicy.
func (*GangSchedulingPolicy) DeepCopyInto ¶ added in v0.35.0
func (in *GangSchedulingPolicy) DeepCopyInto(out *GangSchedulingPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GangSchedulingPolicy) Marshal ¶ added in v0.35.0
func (m *GangSchedulingPolicy) Marshal() (dAtA []byte, err error)
func (*GangSchedulingPolicy) MarshalTo ¶ added in v0.35.0
func (m *GangSchedulingPolicy) MarshalTo(dAtA []byte) (int, error)
func (*GangSchedulingPolicy) MarshalToSizedBuffer ¶ added in v0.35.0
func (m *GangSchedulingPolicy) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (GangSchedulingPolicy) OpenAPIModelName ¶ added in v0.35.0
func (in GangSchedulingPolicy) OpenAPIModelName() string
OpenAPIModelName returns the OpenAPI model name for this type.
func (*GangSchedulingPolicy) Reset ¶ added in v0.35.0
func (m *GangSchedulingPolicy) Reset()
func (*GangSchedulingPolicy) Size ¶ added in v0.35.0
func (m *GangSchedulingPolicy) Size() (n int)
func (*GangSchedulingPolicy) String ¶ added in v0.35.0
func (this *GangSchedulingPolicy) String() string
func (GangSchedulingPolicy) SwaggerDoc ¶ added in v0.35.0
func (GangSchedulingPolicy) SwaggerDoc() map[string]string
func (*GangSchedulingPolicy) Unmarshal ¶ added in v0.35.0
func (m *GangSchedulingPolicy) Unmarshal(dAtA []byte) error
type PodGroup ¶ added in v0.35.0
type PodGroup struct {
// Name is a unique identifier for the PodGroup within the Workload.
// It must be a DNS label. This field is immutable.
//
// +required
Name string `json:"name" protobuf:"bytes,1,opt,name=name"`
// Policy defines the scheduling policy for this PodGroup.
//
// +required
Policy PodGroupPolicy `json:"policy" protobuf:"bytes,3,opt,name=policy"`
}
PodGroup represents a set of pods with a common scheduling policy.
func (*PodGroup) DeepCopy ¶ added in v0.35.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodGroup.
func (*PodGroup) DeepCopyInto ¶ added in v0.35.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PodGroup) MarshalToSizedBuffer ¶ added in v0.35.0
func (PodGroup) OpenAPIModelName ¶ added in v0.35.0
OpenAPIModelName returns the OpenAPI model name for this type.
func (PodGroup) SwaggerDoc ¶ added in v0.35.0
type PodGroupPolicy ¶ added in v0.35.0
type PodGroupPolicy struct {
// Basic specifies that the pods in this group should be scheduled using
// standard Kubernetes scheduling behavior.
//
// +optional
// +oneOf=PolicySelection
Basic *BasicSchedulingPolicy `json:"basic,omitempty" protobuf:"bytes,2,opt,name=basic"`
// Gang specifies that the pods in this group should be scheduled using
// all-or-nothing semantics.
//
// +optional
// +oneOf=PolicySelection
Gang *GangSchedulingPolicy `json:"gang,omitempty" protobuf:"bytes,3,opt,name=gang"`
}
PodGroupPolicy defines the scheduling configuration for a PodGroup.
func (*PodGroupPolicy) DeepCopy ¶ added in v0.35.0
func (in *PodGroupPolicy) DeepCopy() *PodGroupPolicy
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodGroupPolicy.
func (*PodGroupPolicy) DeepCopyInto ¶ added in v0.35.0
func (in *PodGroupPolicy) DeepCopyInto(out *PodGroupPolicy)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PodGroupPolicy) Marshal ¶ added in v0.35.0
func (m *PodGroupPolicy) Marshal() (dAtA []byte, err error)
func (*PodGroupPolicy) MarshalTo ¶ added in v0.35.0
func (m *PodGroupPolicy) MarshalTo(dAtA []byte) (int, error)
func (*PodGroupPolicy) MarshalToSizedBuffer ¶ added in v0.35.0
func (m *PodGroupPolicy) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (PodGroupPolicy) OpenAPIModelName ¶ added in v0.35.0
func (in PodGroupPolicy) OpenAPIModelName() string
OpenAPIModelName returns the OpenAPI model name for this type.
func (*PodGroupPolicy) Reset ¶ added in v0.35.0
func (m *PodGroupPolicy) Reset()
func (*PodGroupPolicy) Size ¶ added in v0.35.0
func (m *PodGroupPolicy) Size() (n int)
func (*PodGroupPolicy) String ¶ added in v0.35.0
func (this *PodGroupPolicy) String() string
func (PodGroupPolicy) SwaggerDoc ¶ added in v0.35.0
func (PodGroupPolicy) SwaggerDoc() map[string]string
func (*PodGroupPolicy) Unmarshal ¶ added in v0.35.0
func (m *PodGroupPolicy) Unmarshal(dAtA []byte) error
type PriorityClass ¶
type PriorityClass struct {
metav1.TypeMeta `json:",inline"`
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
// value represents the integer value of this priority class. This is the actual priority that pods
// receive when they have the name of this class in their pod spec.
Value int32 `json:"value" protobuf:"bytes,2,opt,name=value"`
// globalDefault specifies whether this PriorityClass should be considered as
// the default priority for pods that do not have any priority class.
// Only one PriorityClass can be marked as `globalDefault`. However, if more than
// one PriorityClasses exists with their `globalDefault` field set to true,
// the smallest value of such global default PriorityClasses will be used as the default priority.
// +optional
GlobalDefault bool `json:"globalDefault,omitempty" protobuf:"bytes,3,opt,name=globalDefault"`
// description is an arbitrary string that usually provides guidelines on
// when this priority class should be used.
// +optional
Description string `json:"description,omitempty" protobuf:"bytes,4,opt,name=description"`
// preemptionPolicy is the Policy for preempting pods with lower priority.
// One of Never, PreemptLowerPriority.
// Defaults to PreemptLowerPriority if unset.
// +optional
PreemptionPolicy *apiv1.PreemptionPolicy `json:"preemptionPolicy,omitempty" protobuf:"bytes,5,opt,name=preemptionPolicy"`
}
DEPRECATED - This group version of PriorityClass is deprecated by scheduling.k8s.io/v1/PriorityClass. PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer.
func (*PriorityClass) DeepCopy ¶
func (in *PriorityClass) DeepCopy() *PriorityClass
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PriorityClass.
func (*PriorityClass) DeepCopyInto ¶
func (in *PriorityClass) DeepCopyInto(out *PriorityClass)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PriorityClass) DeepCopyObject ¶
func (in *PriorityClass) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PriorityClass) Marshal ¶
func (m *PriorityClass) Marshal() (dAtA []byte, err error)
func (*PriorityClass) MarshalToSizedBuffer ¶ added in v0.16.4
func (m *PriorityClass) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (PriorityClass) OpenAPIModelName ¶ added in v0.35.0
func (in PriorityClass) OpenAPIModelName() string
OpenAPIModelName returns the OpenAPI model name for this type.
func (*PriorityClass) Reset ¶
func (m *PriorityClass) Reset()
func (*PriorityClass) Size ¶
func (m *PriorityClass) Size() (n int)
func (*PriorityClass) String ¶
func (this *PriorityClass) String() string
func (PriorityClass) SwaggerDoc ¶
func (PriorityClass) SwaggerDoc() map[string]string
func (*PriorityClass) Unmarshal ¶
func (m *PriorityClass) Unmarshal(dAtA []byte) error
type PriorityClassList ¶
type PriorityClassList struct {
metav1.TypeMeta `json:",inline"`
// Standard list metadata
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
// +optional
metav1.ListMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
// items is the list of PriorityClasses
Items []PriorityClass `json:"items" protobuf:"bytes,2,rep,name=items"`
}
PriorityClassList is a collection of priority classes.
func (*PriorityClassList) DeepCopy ¶
func (in *PriorityClassList) DeepCopy() *PriorityClassList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PriorityClassList.
func (*PriorityClassList) DeepCopyInto ¶
func (in *PriorityClassList) DeepCopyInto(out *PriorityClassList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PriorityClassList) DeepCopyObject ¶
func (in *PriorityClassList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*PriorityClassList) Marshal ¶
func (m *PriorityClassList) Marshal() (dAtA []byte, err error)
func (*PriorityClassList) MarshalTo ¶
func (m *PriorityClassList) MarshalTo(dAtA []byte) (int, error)
func (*PriorityClassList) MarshalToSizedBuffer ¶ added in v0.16.4
func (m *PriorityClassList) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (PriorityClassList) OpenAPIModelName ¶ added in v0.35.0
func (in PriorityClassList) OpenAPIModelName() string
OpenAPIModelName returns the OpenAPI model name for this type.
func (*PriorityClassList) Reset ¶
func (m *PriorityClassList) Reset()
func (*PriorityClassList) Size ¶
func (m *PriorityClassList) Size() (n int)
func (*PriorityClassList) String ¶
func (this *PriorityClassList) String() string
func (PriorityClassList) SwaggerDoc ¶
func (PriorityClassList) SwaggerDoc() map[string]string
func (*PriorityClassList) Unmarshal ¶
func (m *PriorityClassList) Unmarshal(dAtA []byte) error
type TypedLocalObjectReference ¶ added in v0.35.0
type TypedLocalObjectReference struct {
// APIGroup is the group for the resource being referenced.
// If APIGroup is empty, the specified Kind must be in the core API group.
// For any other third-party types, setting APIGroup is required.
// It must be a DNS subdomain.
//
// +optional
APIGroup string `json:"apiGroup,omitempty" protobuf:"bytes,1,opt,name=apiGroup"`
// Kind is the type of resource being referenced.
// It must be a path segment name.
//
// +required
Kind string `json:"kind" protobuf:"bytes,2,opt,name=kind"`
// Name is the name of resource being referenced.
// It must be a path segment name.
//
// +required
Name string `json:"name" protobuf:"bytes,3,opt,name=name"`
}
TypedLocalObjectReference allows to reference typed object inside the same namespace.
func (*TypedLocalObjectReference) DeepCopy ¶ added in v0.35.0
func (in *TypedLocalObjectReference) DeepCopy() *TypedLocalObjectReference
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TypedLocalObjectReference.
func (*TypedLocalObjectReference) DeepCopyInto ¶ added in v0.35.0
func (in *TypedLocalObjectReference) DeepCopyInto(out *TypedLocalObjectReference)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TypedLocalObjectReference) Marshal ¶ added in v0.35.0
func (m *TypedLocalObjectReference) Marshal() (dAtA []byte, err error)
func (*TypedLocalObjectReference) MarshalTo ¶ added in v0.35.0
func (m *TypedLocalObjectReference) MarshalTo(dAtA []byte) (int, error)
func (*TypedLocalObjectReference) MarshalToSizedBuffer ¶ added in v0.35.0
func (m *TypedLocalObjectReference) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (TypedLocalObjectReference) OpenAPIModelName ¶ added in v0.35.0
func (in TypedLocalObjectReference) OpenAPIModelName() string
OpenAPIModelName returns the OpenAPI model name for this type.
func (*TypedLocalObjectReference) Reset ¶ added in v0.35.0
func (m *TypedLocalObjectReference) Reset()
func (*TypedLocalObjectReference) Size ¶ added in v0.35.0
func (m *TypedLocalObjectReference) Size() (n int)
func (*TypedLocalObjectReference) String ¶ added in v0.35.0
func (this *TypedLocalObjectReference) String() string
func (TypedLocalObjectReference) SwaggerDoc ¶ added in v0.35.0
func (TypedLocalObjectReference) SwaggerDoc() map[string]string
func (*TypedLocalObjectReference) Unmarshal ¶ added in v0.35.0
func (m *TypedLocalObjectReference) Unmarshal(dAtA []byte) error
type Workload ¶ added in v0.35.0
type Workload struct {
metav1.TypeMeta `json:",inline"`
// Standard object's metadata.
// Name must be a DNS subdomain.
//
// +optional
metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
// Spec defines the desired behavior of a Workload.
//
// +required
Spec WorkloadSpec `json:"spec" protobuf:"bytes,2,opt,name=spec"`
}
Workload allows for expressing scheduling constraints that should be used when managing lifecycle of workloads from scheduling perspective, including scheduling, preemption, eviction and other phases.
func (*Workload) DeepCopy ¶ added in v0.35.0
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Workload.
func (*Workload) DeepCopyInto ¶ added in v0.35.0
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Workload) DeepCopyObject ¶ added in v0.35.0
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Workload) MarshalToSizedBuffer ¶ added in v0.35.0
func (Workload) OpenAPIModelName ¶ added in v0.35.0
OpenAPIModelName returns the OpenAPI model name for this type.
func (Workload) SwaggerDoc ¶ added in v0.35.0
type WorkloadList ¶ added in v0.35.0
type WorkloadList struct {
metav1.TypeMeta `json:",inline"`
// Standard list metadata.
//
// +optional
metav1.ListMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
// Items is the list of Workloads.
Items []Workload `json:"items" protobuf:"bytes,2,rep,name=items"`
}
WorkloadList contains a list of Workload resources.
func (*WorkloadList) DeepCopy ¶ added in v0.35.0
func (in *WorkloadList) DeepCopy() *WorkloadList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkloadList.
func (*WorkloadList) DeepCopyInto ¶ added in v0.35.0
func (in *WorkloadList) DeepCopyInto(out *WorkloadList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*WorkloadList) DeepCopyObject ¶ added in v0.35.0
func (in *WorkloadList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*WorkloadList) Marshal ¶ added in v0.35.0
func (m *WorkloadList) Marshal() (dAtA []byte, err error)
func (*WorkloadList) MarshalTo ¶ added in v0.35.0
func (m *WorkloadList) MarshalTo(dAtA []byte) (int, error)
func (*WorkloadList) MarshalToSizedBuffer ¶ added in v0.35.0
func (m *WorkloadList) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (WorkloadList) OpenAPIModelName ¶ added in v0.35.0
func (in WorkloadList) OpenAPIModelName() string
OpenAPIModelName returns the OpenAPI model name for this type.
func (*WorkloadList) Reset ¶ added in v0.35.0
func (m *WorkloadList) Reset()
func (*WorkloadList) Size ¶ added in v0.35.0
func (m *WorkloadList) Size() (n int)
func (*WorkloadList) String ¶ added in v0.35.0
func (this *WorkloadList) String() string
func (WorkloadList) SwaggerDoc ¶ added in v0.35.0
func (WorkloadList) SwaggerDoc() map[string]string
func (*WorkloadList) Unmarshal ¶ added in v0.35.0
func (m *WorkloadList) Unmarshal(dAtA []byte) error
type WorkloadSpec ¶ added in v0.35.0
type WorkloadSpec struct {
// ControllerRef is an optional reference to the controlling object, such as a
// Deployment or Job. This field is intended for use by tools like CLIs
// to provide a link back to the original workload definition.
// When set, it cannot be changed.
//
// +optional
ControllerRef *TypedLocalObjectReference `json:"controllerRef,omitempty" protobuf:"bytes,1,opt,name=controllerRef"`
// PodGroups is the list of pod groups that make up the Workload.
// The maximum number of pod groups is 8. This field is immutable.
//
// +required
// +listType=map
// +listMapKey=name
PodGroups []PodGroup `json:"podGroups" protobuf:"bytes,2,rep,name=podGroups"`
}
WorkloadSpec defines the desired state of a Workload.
func (*WorkloadSpec) DeepCopy ¶ added in v0.35.0
func (in *WorkloadSpec) DeepCopy() *WorkloadSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkloadSpec.
func (*WorkloadSpec) DeepCopyInto ¶ added in v0.35.0
func (in *WorkloadSpec) DeepCopyInto(out *WorkloadSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*WorkloadSpec) Marshal ¶ added in v0.35.0
func (m *WorkloadSpec) Marshal() (dAtA []byte, err error)
func (*WorkloadSpec) MarshalTo ¶ added in v0.35.0
func (m *WorkloadSpec) MarshalTo(dAtA []byte) (int, error)
func (*WorkloadSpec) MarshalToSizedBuffer ¶ added in v0.35.0
func (m *WorkloadSpec) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (WorkloadSpec) OpenAPIModelName ¶ added in v0.35.0
func (in WorkloadSpec) OpenAPIModelName() string
OpenAPIModelName returns the OpenAPI model name for this type.
func (*WorkloadSpec) Reset ¶ added in v0.35.0
func (m *WorkloadSpec) Reset()
func (*WorkloadSpec) Size ¶ added in v0.35.0
func (m *WorkloadSpec) Size() (n int)
func (*WorkloadSpec) String ¶ added in v0.35.0
func (this *WorkloadSpec) String() string
func (WorkloadSpec) SwaggerDoc ¶ added in v0.35.0
func (WorkloadSpec) SwaggerDoc() map[string]string
func (*WorkloadSpec) Unmarshal ¶ added in v0.35.0
func (m *WorkloadSpec) Unmarshal(dAtA []byte) error